<?php

/**
 * @version     1.7.0
 * @package    Com_Gavoting
 * @author     Glenn Arkell <glenn@glennarkell.com.au>
 * @copyright  2020 Glenn Arkell
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 */

//namespace GlennArkell\Component\Gavoting\Administrator\Helper;

// No direct access
defined('_JEXEC') or die;

use \Joomla\CMS\Factory;
use \Joomla\Data\DataObject;
use \Joomla\CMS\Language\Text;
use \Joomla\CMS\MVC\Model\ListModel;
use \Joomla\CMS\MVC\Model\BaseDatabaseModel;
use \Joomla\CMS\Installer\Installer;
use \Joomla\Filesystem\Path;
use \Joomla\CMS\Toolbar\Toolbar;
use \Joomla\CMS\Toolbar\ToolbarHelper;
use \Joomla\CMS\Uri\Uri;
use \Joomla\CMS\Component\ComponentHelper;
use \Joomla\CMS\User\UserHelper;
use \Joomla\CMS\Categories\Categories;
use \Joomla\CMS\Table\Table;
use \Joomla\CMS\Date\Date;

/**
 * Gavoting helper.
 *
 * @since  1.6
 */
class GanotificationHelper
{
	/**
	 * Setup the email notifications
	 * @params object nomination	user record plus profile
	 * @params object nominator		user record
	 * @params object seconder		user record
	 * @params object position		position recorde
	 * @params int nom_id			nomination id reference
	 * @return boolean
	 */
    public static function sendNominationEmail($nomination = 0, $nominator = 0, $seconder = 0, $position = 0, $nom_id = 0, $params)
	{
		$test_comp = $params->get('test_comp', 0);
		$ignNomEmail = false;
		$ignNeeEmail = false;
		$ignSecEmail = false;
		$link = Uri::base().'/index.php?option=com_gavoting&task=nomination.agree&id='.$nom_id;
		//$pos = GavotingHelper::getPosition($position);
        $req_sec_nom = $params->get('req_sec_nom');
        $single_mship = $params->get('single_mship');
        $proffield = $params->get('profile_field');
        $proflocal = $params->get('profile_suffix');
        $profprefix = 'profile'.$proflocal.'.';
        $prof_key = $profprefix.$proffield;
        $auto_accept = $params->get('auto_accept',0);
        $ignore_prefix = $params->get('ignore_prefix','noemail');
        $emailLen = strlen($ignore_prefix);
        if ($emailLen > 0 && substr($nomination->email, 0, $emailLen) == $ignore_prefix ) {
			$ignNomEmail = true;
		}
        if ($emailLen > 0 && substr($nominator->email, 0, $emailLen) == $ignore_prefix ) {
			$ignNeeEmail = true;
		}
        if ($emailLen > 0 && substr($seconder->email, 0, $emailLen) == $ignore_prefix ) {
			$ignSecEmail = true;
		}

		$subject = Text::_('COM_GAVOTING_NOMINATION_EMAIL_SUBJECT');
		if ($auto_accept && $nomination->id == $nominator->id) {
			// don't bother to send this email
		} else {
			$recipients = array($nomination->email);
			$nbody = '<p>'.Text::_('COM_GAVOTING_NOMINATION_EMAIL_DEAR').$nomination->nom_name.',</p>';
			$nbody .= '<p>'.Text::_('COM_GAVOTING_NOMINATION_EMAIL_INTRO').$position->position_name.'</p>';
			if ($req_sec_nom) {
				$nbody .= '<p>'.Text::sprintf('COM_GAVOTING_NOMINATION_EMAIL_NOM_SEC',$nominator->name,$seconder->name).'.</p>';
			} else {
				$nbody .= '<p>'.Text::sprintf('COM_GAVOTING_NOMINATION_EMAIL_NOM_NOSEC',$nominator->name).'.</p>';
			}
			$nbody .= '<p>'.Text::_('COM_GAVOTING_NOMINATION_EMAIL_BODY').'</p>';
			$nbody .= '<p><a href="'.$link.'" alt="" title="'.Text::_('COM_GAVOTING_AGREE_BUTTON');
			$nbody .= '">'.Text::_('COM_GAVOTING_ACCEPT_NOMINATION').'</a></p>';
			$nbody .= '<p>'.Text::_('COM_GAVOTING_REMEMBER_LOGIN').'</p>';
			if (!$ignNomEmail && !$test_comp) {
				self::sendEmail($recipients, $nbody, $subject, 0, 0);
			}
		}

		if (!$ignNeeEmail && !$ignSecEmail) {
			$recipients = array($nominator->email, $seconder->email);
		} elseif (!$ignNeeEmail && $ignSecEmail) {
			$recipients = array($nominator->email);
		} elseif ($ignNeeEmail && !$ignSecEmail) {
			$recipients = array($seconder->email);
		} else {
			return true;
		}

		$recipients = array($nominator->email, $seconder->email);
		if ($req_sec_nom) {
			$body = '<p>'.Text::_('COM_GAVOTING_NOMINATION_EMAIL_DEAR').$nominator->name.' and '.$seconder->name.',</p>';
			$body .= '<p>'.Text::sprintf('COM_GAVOTING_NOMINATED_EMAIL_INTRO',$nomination->nom_name,$position->position_name).'</p>';
		} else {
			$body = '<p>'.Text::_('COM_GAVOTING_NOMINATION_EMAIL_DEAR').$nominator->name.',</p>';
			$body .= '<p>'.Text::sprintf('COM_GAVOTING_NOMINATED_EMAIL_INTRO_NOSEC',$nomination->nom_name,$position->position_name).'</p>';
		}

		$body .= '<p>'.Text::_('COM_GAVOTING_NOMINATED_EMAIL_BODY').'</p>';
		
		if (!$test_comp) {
			self::sendEmail($recipients, $body, $subject, 0, 0);
		}

        return true;
	}

	/**
	 * Setup the email notifications of voting
	 * @params object voter		user record
	 * @params object proxy		user record
	 * @params array posvotes	position and vote collection
	 * @params object params	component parameters
	 * @return boolean
	 */
	public static function sendVotingEmail($voter = 0, $proxy = 0, $posvotes, $params)
	{
		$test_comp = $params->get('test_comp', 0);
		$subject = Text::_('COM_GAVOTING_VOTING_EMAIL_SUBJECT');
		$body = '<p>'.Text::sprintf('COM_GAVOTING_VOTING_EMAIL_DEAR',$proxy->name).',</p>';
		$body .= '<p>'.Text::sprintf('COM_GAVOTING_VOTING_EMAIL_INTRO',$voter->name).'</p>';
		$body .= '<p>';
		foreach ($posvotes AS $k => $v) {
			$body .= $k.' = '.$v.'<br />';
		}
		$body .= '</p><p> </p><p>'.Text::_('COM_GAVOTING_VOTING_DISPUTE').'</p>';

		$ignore_prefix = $params->get('ignore_prefix','noemail');
		$emailLen = strlen($ignore_prefix);

		if (substr($voter->email, 0, $emailLen) == $ignore_prefix ) {
			// don't do anything
		} else {
			$recipients = array($voter->email);
			if (!$test_comp) {
				self::sendEmail($recipients, $body, $subject, 0, 0);
			}
			Factory::getApplication()->enqueueMessage(Text::sprintf('COM_GAVOTING_VOTE_CAST_OK',$voter->name), 'message');
		}
		if (substr($proxy->email, 0, $emailLen) == $ignore_prefix ) {
			// don't do anything
		} else {
			$recipients = array($proxy->email);
			if (!$test_comp) {
				self::sendEmail($recipients, $body, $subject, 0, 0);
			}
			Factory::getApplication()->enqueueMessage(Text::sprintf('COM_GAVOTING_VOTE_CAST_OK',$proxy->name), 'message');
		}

		return true;
	}

	/**
	 * Setup the email notifications of proxy
	 * @params object voter		user record
	 * @params object proxy		user record
	 * @params array posvotes	position and vote collection
	 * @params object params	component parameters
	 * @return boolean
	 */
	public static function sendProxyEmail($voter = 0, $proxy = 0, $posvotes, $params)
	{
		$test_comp = $params->get('test_comp', 0);
		$subject = Text::_('COM_GAVOTING_PROXY_EMAIL_SUBJECT');
		$body = '<p>'.Text::sprintf('COM_GAVOTING_PROXY_EMAIL_DEAR',$proxy->name).',</p>';
		$body .= '<p>'.Text::sprintf('COM_GAVOTING_PROXY_EMAIL_INTRO',$voter->name).'</p>';
		$body .= '<p>';
		foreach ($posvotes AS $k => $v) {
			$body .= $k.' = '.$v.'<br />';
		}
		$body .= '</p><p> </p>';

		$ignore_prefix = $params->get('ignore_prefix','noemail');
		$emailLen = strlen($ignore_prefix);

		if (substr($voter->email, 0, $emailLen) == $ignore_prefix ) {
			// don't do anything
		} else {
			$recipients = array($voter->email);
			if (!$test_comp) {
				self::sendEmail($recipients, $body, $subject, 0, 0);
			}
			Factory::getApplication()->enqueueMessage(Text::sprintf('COM_GAVOTING_VOTE_CAST_OK',$voter->name), 'message');
		}
		if (substr($proxy->email, 0, $emailLen) == $ignore_prefix ) {
			// don't do anything
		} else {
			$recipients = array($proxy->email);
			if (!$test_comp) {
				self::sendEmail($recipients, $body, $subject, 0, 0);
			}
			Factory::getApplication()->enqueueMessage(Text::sprintf('COM_GAVOTING_VOTE_CAST_OK',$proxy->name), 'message');
		}

		return true;
	}

	/**
	 * Setup the email notifications of proxy
	 * @params object voter		user record
	 * @params object proxy		user record
	 * @params array posvotes	position and vote collection
	 * @params object params	component parameters
	 * @return boolean
	 */
	public static function sendProxyNotification($data = 0, $params)
	{
		$test_comp = $params->get('test_comp', 0);
		$voter = Factory::getUser($data['voter_id']);
		$proxy = Factory::getUser($data['user_id']);
		$subject = Text::_('COM_GAVOTING_PROXY_EMAIL_SUBJECT');
		$body = '<p>'.Text::sprintf('COM_GAVOTING_PROXY_EMAIL_DEAR',$voter->name).',</p>';
		$body .= '<p>'.Text::sprintf('COM_GAVOTING_PROXY_EMAIL_INTRO',$proxy->name).'</p>';
		$body .= '<p> </p>';
		$recipients = array();

		$ignore_prefix = $params->get('ignore_prefix','noemail');
		$emailLen = strlen($ignore_prefix);

		if (substr($voter->email, 0, $emailLen) != $ignore_prefix ) {
			$recipients[] = $voter->email;
		}
		if (substr($proxy->email, 0, $emailLen) != $ignore_prefix ) {
			$recipients[] = $proxy->email;
		}

		if (!empty($recipients)) {
			self::sendEmail($recipients, $body, $subject, 0, 0);
		}

		return true;
	}

    public static function sendEmail($recipients, $body, $subject, $attachfile, $replyTo = 0)
	{
	    $app		= Factory::getApplication();
        $mailfrom	= $app->get('mailfrom');       // system email address
        $fromname	= $app->get('fromname');       // Site name or system name
        $body .= '<p></p><p>'.$fromname.'</p>';

        // Build the email and send
        $mail = Factory::getMailer();
        $mail->isHTML(true);
		$mail->addRecipient($recipients);
		$mail->setSender(array($mailfrom, $fromname));
		$mail->setSubject($subject);
		$mail->setBody($body);
		if (is_file($attachfile)) {
            $mail->addAttachment($attachfile);
        }
		if ($replyTo) {
            $mail->setReplyTo($replyTo);
        }
        
        // check if testing so no need to send emails
		if (!$test_comp) {
			$sent = $mail->Send();
		}

        return true;
	}

}

