<?php
/**
 * @version    1.7.0
 * @package    Com_Gavoting
 * @author     Glenn Arkell <glenn@glennarkell.com.au>
 * @copyright  2020 Glenn Arkell
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 */
// No direct access
defined('_JEXEC') or die;

use \Joomla\CMS\HTML\HTMLHelper;
use \Joomla\CMS\Factory;
use \Joomla\CMS\Uri\Uri;
use \Joomla\CMS\Router\Route;
use \Joomla\CMS\Language\Text;

HTMLHelper::_('bootstrap.tooltip');
HTMLHelper::_('behavior.multiselect');
HTMLHelper::_('formbehavior.chosen', 'select');

// Load admin language file
$lang = Factory::getLanguage();
$lang->load('com_gavoting', JPATH_ADMINISTRATOR);

$user    = Factory::getUser();
$canEdit = GavotingHelper::canUserEdit($this->item, $user);
$canCheckin = $user->authorise('core.manage', 'com_gavoting');
$canVote = $user->authorise('core.vote', 'com_gavoting');
$close_vote = GavotingHelper::votingClosed();
$today = GavotingHelper::getTodaysDate();
$electYearCat = GavotingHelper::getElectionYear();
$proxyvoterSet = GavotingHelper::doesProxyExist($user->id, $electYearCat->id);
$proxyvoters = GavotingHelper::areYouAProxyvoter($user->id, $electYearCat->id);
$proxyvoterList = '';
if (is_array($proxyvoters) && !empty($proxyvoters)) {
	foreach ($proxyvoters AS $p) { $proxyvoterList .= $p->voter_id_name . ', '; }
	$proxyvoterList = substr($proxyvoterList, 0, -2);
}
$hasProxy = GavotingHelper::hasProxy($user->id);

$restrict_voters = $this->params->get('restrict_voters',0);
$voters_user_gp = $this->params->get('voters_user_gp',0);
if ($canVote && $restrict_voters) {
	$canVote = GavotingHelper::checkAccessGroup($user->id, $voters_user_gp);
}

?>

<h2 class="item-title" intemprop="headline"><?php echo Text::_('COM_GAVOTING_PROXY_SETMINE'); ?></h2>

<div class="proxyvoter-edit front-end-edit">
	<?php if ($close_vote) : ?>
		<h3><?php echo Text::_('COM_GAVOTING_PROXYS_CLOSED'); ?></h3>
	<?php elseif (!$canVote): ?>
		<h2><?php echo Text::_('COM_GAVOTING_ERROR_MESSAGE_NOT_AUTHORISED'); ?></h2>
	<?php else : ?>
		<?php if (isset($hasProxy->principal)) : ?>
			<h3>
				<?php echo Text::sprintf('COM_GAVOTING_ALREADY_PROXYED', $hasProxy->principal, $hasProxy->principal); ?>
			</h3>
		<?php elseif ($proxyvoterList > '') : ?>
			<p><strong><?php echo Text::sprintf('COM_GAVOTING_PROXY_YOUAREAPROXYVOTER', $proxyvoterList); ?></strong></p>
			<div class="row-fluid span11">
				<?php foreach ($proxyvoters AS $prx) : ?>
					<p>
					<a class="btn btn-secondary"
						href="<?php echo Route::_('index.php?option=com_gavoting&task=proxyvoter.remove&id='.(int) $prx->id .'&user_id='.(int) $prx->user_id.'&voter_id='.(int) $prx->voter_id); ?>">
						<i class="icon-trash"></i>
					</a> <?php echo Text::sprintf('COM_GAVOTING_PROXY_REMOVE', $prx->voter_id_name); ?>
					</p>
				<?php endforeach; ?>
			</div>
		<?php else : ?>
			<?php if (!$canEdit) : ?>
				<h3>
					<?php throw new Exception(Text::_('COM_GAVOTING_ERROR_MESSAGE_NOT_AUTHORISED'), 403); ?>
				</h3>
			<?php else : ?>
	
				<form id="form-proxyvoter"
					  action="<?php echo Route::_('index.php?option=com_gavoting&task=proxyvoterform.save'); ?>"
					  method="post" class="form-validate form-horizontal" enctype="multipart/form-data">
		
					<input type="hidden" name="jform[id]" value="<?php echo $this->item->id; ?>" />
					<input type="hidden" name="jform[ordering]" value="<?php echo $this->item->ordering; ?>" />
					<input type="hidden" name="jform[state]" value="<?php echo $this->item->state; ?>" />
					<input type="hidden" name="jform[checked_out]" value="<?php echo $this->item->checked_out; ?>" />
					<input type="hidden" name="jform[checked_out_time]" value="<?php echo $this->item->checked_out_time; ?>" />
					<input type="hidden" name="jform[created_by]" value="<?php echo $this->item->created_by; ?>" />
					<input type="hidden" name="jform[modified_by]" value="<?php echo $this->item->modified_by; ?>" />
					<input type="hidden" name="jform[created_date]" value="<?php echo $this->item->created_date; ?>" />
					<input type="hidden" name="jform[modified_date]" value="<?php echo $this->item->modified_date; ?>" />
					<input type="hidden" name="jform[cat_id]" value="<?php echo $this->item->cat_id; ?>" />
	
					<?php echo HTMLHelper::_('bootstrap.startTabSet', 'myTab', array('active' => 'proxyvoter')); ?>
					<?php echo HTMLHelper::_('bootstrap.addTab', 'myTab', 'proxyvoter', Text::_('COM_GAVOTING_TITLE_PROXYVOTER', true)); ?>
					<div class="row-fluid">
						<div class="span10 form-horizontal">
							<fieldset class="adminform">
								<?php echo $this->form->renderField('cat_id_name'); ?>
								<?php if ($canCheckin) : ?>
									<?php echo $this->form->renderField('voter_id'); ?>
								<?php else : ?>
									<?php echo $this->form->renderField('voter_id_name'); ?>
									<input type="hidden" name="jform[voter_id]" value="<?php echo $this->item->voter_id; ?>" />
								<?php endif; ?>
								<?php echo $this->form->renderField('user_id'); ?>
							</fieldset>
						</div>
					</div>
					<?php echo HTMLHelper::_('bootstrap.endTab'); ?>
	
					<?php echo HTMLHelper::_('bootstrap.endTabSet'); ?>
		
					<div class="control-group">
						<div class="controls">
	
							<?php if ($this->canSave): ?>
								<button type="submit" class="validate btn btn-primary">
									<?php echo Text::_('JSUBMIT'); ?>
								</button>
							<?php endif; ?>
							<a class="btn btn-secondary"
							   href="<?php echo Route::_('index.php?option=com_gavoting&task=proxyvoterform.cancel'); ?>"
							   title="<?php echo Text::_('JCANCEL'); ?>">
								<?php echo Text::_('JCANCEL'); ?>
							</a>
						</div>
					</div>
		
					<input type="hidden" name="option" value="com_gavoting"/>
					<input type="hidden" name="task" value="proxyvoterform.save"/>
					<?php echo HTMLHelper::_('form.token'); ?>
				</form>
			<?php endif; ?>
		<?php endif; ?>
	<?php endif; ?>
</div>
