<?php
/**
 * @version    1.7.0
 * @package    Com_Gavoting
 * @author     Glenn Arkell <glenn@glennarkell.com.au>
 * @copyright  2020 Glenn Arkell
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 */
// No direct access
defined('_JEXEC') or die;

use \Joomla\CMS\HTML\HTMLHelper;
use \Joomla\CMS\Factory;
use \Joomla\CMS\Uri\Uri;
use \Joomla\CMS\Router\Route;
use \Joomla\CMS\Language\Text;
use \Joomla\CMS\Layout\LayoutHelper;
use \Joomla\CMS\User\UserHelper;
use \Joomla\CMS\Date\Date;

HTMLHelper::_('bootstrap.tooltip');
HTMLHelper::_('behavior.multiselect');
HTMLHelper::_('formbehavior.chosen', 'select');

// Load admin language file
$lang = Factory::getLanguage();
$lang->load('com_gavoting', JPATH_ADMINISTRATOR);

$user       = Factory::getUser();
$userId     = $user->id;
$listOrder  = $this->state->get('list.ordering');
$listDirn   = $this->state->get('list.direction');
$canCreate  = $user->authorise('core.create', 'com_gavoting');
$canEdit    = $user->authorise('core.edit', 'com_gavoting');
$canCheckin = $user->authorise('core.manage', 'com_gavoting');
$canChange  = $user->authorise('core.edit.state', 'com_gavoting');
$canDelete  = $user->authorise('core.delete', 'com_gavoting');
$canNominate  = $user->authorise('core.nominate', 'com_gavoting');
$canVote  = $user->authorise('core.vote', 'com_gavoting');
$canProxyvoter  = $user->authorise('core.proxyvoter', 'com_gavoting');
$showVotes = $this->params->get('show_votes',0);
$notag_colour = $this->params->get('notag_colour','#a51f18');
$req_sec_mot = $this->params->get('req_sec_mot',1);
$cols = 5;
$padSpace = '&nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp;';

if ($this->params->get('multi_users', 0)) {
	$linked_field = $this->params->get('linkcust_field', 0);
	$linkedUser = GavotingHelper::getCustomField($user->id, $linked_field);
} else {
    $linkedUser = 0;
}
$votingClosed = GavotingHelper::votingClosed();
$close_noms = GavotingHelper::nominationsClosed();

if ($canProxyvoter && ($votingClosed || $close_noms)) {$canProxyvoter = false;}

$restrict_voters = $this->params->get('restrict_voters',0);
$voters_user_gp = $this->params->get('voters_user_gp',0);
if ($canVote && $restrict_voters) {
	$canVote = GavotingHelper::checkAccessGroup($user->id, $voters_user_gp);
}

?>

<h2 class="item-title" intemprop="headline"><?php echo Text::_('COM_GAVOTING_TITLE_PROXYVOTERS'); ?></h2>

<form action="<?php echo htmlspecialchars(Uri::getInstance()->toString()); ?>" method="post"
      name="adminForm" id="adminForm">

	<?php echo LayoutHelper::render('default_filter', array('view' => $this), dirname(__FILE__)); ?>

    <div class="table-responsive">
	<table class="table table-striped" id="proxyvoterList">
		<thead>
		<tr>
			<th width="25%" class="left">
				<?php echo HTMLHelper::_('grid.sort',  'COM_GAVOTING_PROXYVOTERS_VOTER_ID', 'voter_id_name', $listDirn, $listOrder); ?>
			</th>
			<th width="25%" class="center">
				<?php echo HTMLHelper::_('grid.sort',  'COM_GAVOTING_PROXYVOTERS_CAT_ID', 'cat_id_name', $listDirn, $listOrder); ?>
			</th>
			<th width="25%" class="left">
				<?php echo HTMLHelper::_('grid.sort',  'COM_GAVOTING_PROXYVOTERS_USER_ID', 'user_id_name', $listDirn, $listOrder); ?>
			</th>

			<?php if ($canCheckin || $canDelete): ?>
				<th width="25%" class="center">
					<?php echo Text::_('COM_GAVOTING_ACTIONS'); ?>
				</th>
			<?php endif; ?>

		</tr>
		</thead>
		<tfoot>
		<tr>
			<td colspan="<?php echo isset($this->items[0]) ? count(get_object_vars($this->items[0])) : 10; ?>">
				<?php echo $this->pagination->getListFooter(); ?>
			</td>
		</tr>
		</tfoot>
		<tbody>
		<?php foreach ($this->items as $i => $item) : ?>
			<?php
				$canEdit = $user->authorise('core.edit', 'com_gavoting');
				if (!$canEdit && $user->authorise('core.edit.own', 'com_gavoting')) {
					$canEdit = Factory::getUser()->id == $item->user_id;
				}

			?>


			<tr class="row<?php echo $i % 2; ?>">
				<td>
					<?php if (isset($item->checked_out) && $item->checked_out) : ?>
						<?php echo HTMLHelper::_('jgrid.checkedout', $i, $item->uEditor, $item->checked_out_time, 'proxyvoters.', $canCheckin); ?>
					<?php endif; ?>
					<?php if ($canEdit): ?>
						<a href="<?php echo Route::_('index.php?option=com_gavoting&view=proxyvoter&id='.(int) $item->id); ?>">
							<?php echo $item->voter_id_name; ?>
						</a>
					<?php else : ?>
						<?php echo $item->voter_id_name; ?>
					<?php endif; ?>
				</td>
				<td class="center">
					<?php echo $item->cat_id_name; ?>
				</td>
				<td class="left">
					<?php echo $item->user_id_name; ?>
				</td>

				<?php if ($canCheckin || $canDelete || $canVote): ?>
	                <?php $cols = $cols == 7 ? 8 : 6; ?>
					<td class="center">
						<?php if ($canCheckin): ?>
							<a href="<?php echo Route::_('index.php?option=com_gavoting&task=proxyvoterform.edit&id=' . $item->id, false, 2); ?>" class="btn btn-mini" type="button" title="<?php echo Text::_('COM_GAVOTING_EDIT_RECORD'); ?>"><i class="icon-edit" ></i></a>
						<?php endif; ?>
						<?php if ($canDelete): ?>
							<a href="<?php echo Route::_('index.php?option=com_gavoting&task=proxyvoterform.remove&id=' . $item->id, false, 2); ?>" class="btn btn-mini delete-button" type="button" title="<?php echo Text::_('COM_GAVOTING_DELETE_RECORD'); ?>"><i class="icon-trash" ></i></a>
							<a href="<?php echo Route::_('index.php?option=com_gavoting&task=proxyvoterform.archive&id=' . $item->id, false, 2); ?>" class="btn btn-mini" type="button" title="<?php echo Text::_('COM_GAVOTING_ARCHIVE_RECORD'); ?>"><i class="icon-archive" ></i></a>
						<?php endif; ?>
					</td>
				<?php endif; ?>

			</tr>
		<?php endforeach; ?>
		</tbody>
	</table>
    </div>

	<?php if ($canVote) : ?>
		<a href="<?php echo Route::_('index.php?option=com_gavoting&task=proxyvoterform.edit&id=0', false, 0); ?>"
		   class="btn btn-success btn-small"><i class="icon-plus"></i> <?php echo Text::_('COM_GAVOTING_ADD_ITEM'); ?>
		</a>
	<?php endif; ?>

	<input type="hidden" name="task" value=""/>
	<input type="hidden" name="boxchecked" value="0"/>
	<input type="hidden" name="filter_order" value="<?php echo $listOrder; ?>"/>
	<input type="hidden" name="filter_order_Dir" value="<?php echo $listDirn; ?>"/>
	<?php echo HTMLHelper::_('form.token'); ?>
</form>

<?php if($canDelete) : ?>
<script type="text/javascript">

	jQuery(document).ready(function () {
		jQuery('.delete-button').click(deleteItem);
	});

	function deleteItem() {

		if (!confirm("<?php echo Text::_('COM_GAVOTING_DELETE_MESSAGE'); ?>")) {
			return false;
		}
	}
</script>
<?php endif; ?>
