<?php
/**
 * @version    1.7.0
 * @package    Com_Gavoting
 * @author     Glenn Arkell <glenn@glennarkell.com.au>
 * @copyright  2020 Glenn Arkell
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 */

// No direct access
defined('_JEXEC') or die;

use \Joomla\CMS\HTML\HTMLHelper;
use \Joomla\CMS\Factory;
use \Joomla\CMS\Uri\Uri;
use \Joomla\CMS\Router\Route;
use \Joomla\CMS\Language\Text;
use \Joomla\CMS\Date\Date;
use \Joomla\CMS\Layout\LayoutHelper;

JHtml::_('bootstrap.tooltip');
JHtml::_('behavior.multiselect');
JHtml::_('formbehavior.chosen', 'select');

$app = Factory::getApplication();
$input = $app->input;

// Load admin language file
$lang = Factory::getLanguage();
$lang->load('com_gavoting', JPATH_ADMINISTRATOR);

$user    = Factory::getUser();
$canVote  = $user->authorise('core.vote', 'com_gavoting');
$this->item->voting_user = $user->id;
$this->item->canEdit = GavotingHelper::canUserEdit($this->item, $user);

$this->item->nomsClosed = GavotingHelper::nominationsClosed();
$this->item->votingClosed = GavotingHelper::votingClosed();
$this->item->votingOpen = GavotingHelper::votingOpen();

$restrict_voters = $this->params->get('restrict_voters',0);
$voters_user_gp = $this->params->get('voters_user_gp',0);
if ($canVote && $restrict_voters) {
	$canVote = GavotingHelper::checkAccessGroup($user->id, $voters_user_gp);
}

if ($this->params->get('multi_users', 0)) {
	$linked_field = $this->params->get('linkcust_field', 0);
	$linkedUser = GavotingHelper::getCustomField($user->id, $linked_field);
} else {
    $linkedUser = 0;
}
$this->item->hasVoted = GavotingHelper::hasVoted($user->id, 0, $linkedUser);
$this->item->params = $this->params;
$this->item->canSave = $this->canSave;
$this->item->form = $this->form;

/* -------   Check if principal/owner of vote has delegated a proxy  ------- */
/* -------   returns an object of the proxy record or boolean on null  ----- */
$this->item->proxyVote = GavotingHelper::checkProxySet($user->id);
$proxySet = (isset($this->item->proxyVote) && !empty($this->item->proxyVote)) ? true : false;

$prevPos='';
$cntr=0;

?>

<div class="voter-edit front-end-edit">
<?php if ($this->item->hasVoted): ?>
	<h2><?php echo Text::_('COM_GAVOTING_NOMINATIONS_ALREADY_VOTED'); ?></h2>
<?php elseif (!$canVote): ?>
	<h2><?php echo Text::_('COM_GAVOTING_ERROR_MESSAGE_NOT_AUTHORISED'); ?></h2>
<?php else: ?>

	<?php if ($proxySet): ?>
		<h2><?php echo Text::sprintf('COM_GAVOTING_PROXY_ALREADY_SET', $this->item->proxyVote->name); ?></h2>
	<?php else: ?>

		<?php if (!$this->item->nomsClosed): ?>
			<h2><?php echo Text::_('COM_GAVOTING_NOMINATIONS_STILL_OPEN'); ?></h2>
		<?php else: ?>
			<?php if (!$this->item->canEdit) : ?>
				<h3>
					<?php throw new \Exception(Text::_('COM_GAVOTING_ERROR_MESSAGE_NOT_AUTHORISED'), 403); ?>
				</h3>
			<?php else : ?>
				<?php if ($this->item->votingClosed): ?>
					<h2><?php echo Text::_('COM_GAVOTING_VOTING_CLOSED'); ?></h2>
				<?php else: ?>
					<?php if (!$this->item->votingOpen): ?>
						<h2><?php echo Text::_('COM_GAVOTING_VOTING_NOT_OPEN'); ?></h2>
					<?php else : ?>
						<?php if (!empty($this->item->nominations) && $this->item->nominations > ''): ?>
		
							<?php /* **************************   Voting Form  *********************************/  ?>
							
							<?php echo LayoutHelper::render('default_voting', array('data' => $this->item), dirname(__FILE__)); ?>
		
						<?php else : ?>
							<?php echo Text::_('COM_GAVOTING_NO_NOMINATIONS'); ?>
						<?php endif; ?>
					<?php endif; ?>
				<?php endif; ?>
			<?php endif; ?>
		<?php endif; ?>
	<?php endif; ?>
<?php endif; ?>
</div>
