<?php
/**
 * @version    1.7.0
 * @package    Com_Gavoting
 * @author     Glenn Arkell <glenn@glennarkell.com.au>
 * @copyright  2020 Glenn Arkell
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 */
// No direct access
defined('_JEXEC') or die;

use \Joomla\CMS\HTML\HTMLHelper;
use \Joomla\CMS\Factory;
use \Joomla\CMS\Router\Route;
use \Joomla\CMS\Language\Text;

// Load admin language file
$lang = Factory::getLanguage();
$lang->load('com_gavoting', JPATH_ADMINISTRATOR);

$nominations = $displayData['data'];

// setup the parameters
$proxy_type = $nominations->params->get('proxy_type');
$dupl_vote = $nominations->params->get('dupl_vote', 1);
$reg_proxy = $nominations->params->get('reg_proxy', 1);
$proxyCnt = GavotingHelper::countProxyVotes($nominations->voting_user);
$prevPos='';
$cntr=0;

?>

<h2><?php echo Text::_('COM_GAVOTING_VOTER_SUBMIT_TEXT'); ?></h2>
<form id="form-voter"
	  action="<?php echo Route::_('index.php?option=com_gavoting&task=voterform.save'); ?>"
	  method="post" class="form-validate form-horizontal" enctype="multipart/form-data">

	<input type="hidden" name="jform[id]" value="<?php echo $nominations->id; ?>" />
	<input type="hidden" name="jform[ordering]" value="<?php echo $nominations->ordering; ?>" />
	<input type="hidden" name="jform[state]" value="<?php echo $nominations->state; ?>" />
	<input type="hidden" name="jform[checked_out]" value="<?php echo $nominations->checked_out; ?>" />
	<input type="hidden" name="jform[checked_out_time]" value="<?php echo $nominations->checked_out_time; ?>" />
	<input type="hidden" name="jform[created_by]" value="<?php echo $nominations->created_by; ?>" />
	<input type="hidden" name="jform[modified_by]" value="<?php echo $nominations->modified_by; ?>" />
	<input type="hidden" name="jform[created_date]" value="<?php echo $nominations->created_date; ?>" />
	<input type="hidden" name="jform[modified_date]" value="<?php echo $nominations->modified_date; ?>" />
	<input type="hidden" name="jform[user_id]" value="<?php echo $nominations->voting_user; ?>" />
	<input type="hidden" name="jform[cat_id]" value="<?php echo $nominations->cat_id; ?>" />


	<?php /* ------------  Set up displayed text explaining Proxy settings   ------------ */ ?>
	<div>
		<span style="color:red;">
			<?php if ($proxy_type == 0) : ?>
				<?php if ($dupl_vote) : ?>
					<?php echo Text::_('COM_GAVOTING_PROXYVOTER_GENERAL_DUPYES'); ?>
				<?php else : ?>
					<?php echo Text::_('COM_GAVOTING_PROXYVOTER_GENERAL_DUPNO'); ?>
				<?php endif; ?>
			<?php elseif ($proxy_type == 1) : ?>
				<?php echo Text::_('COM_GAVOTING_PROXYVOTER_MESSAGE'); ?><br />
				<?php echo Text::_('COM_GAVOTING_PROXYVOTER_SPECIFIC'); ?>

			<?php elseif ($proxy_type == 2) : ?>
				<?php echo Text::_('COM_GAVOTING_PROXYVOTER_MESSAGE'); ?><br />
				<?php echo Text::_('COM_GAVOTING_PROXY_HYBRID'); ?>
			<?php endif; ?>
		</span>
	</div>
	<?php if ($proxy_type == 0) : ?>
		<?php if ($dupl_vote) : ?>
			<?php if ($proxyCnt) : ?>
				<div style="color:red; width:100%;" class="spacerheader center"><?php echo Text::sprintf('COM_GAVOTING_PROXYVOTER_COUNT', $proxyCnt); ?></div>
			<?php endif; ?>
		<?php else : ?>
			<div style="color:red; width:100%;" class="spacerheader center"><?php echo Text::_('COM_GAVOTING_PROXYVOTER_WARNING'); ?></div>
		<?php endif; ?>
	<?php endif; ?>


	<?php /* ------------  If proxy delegates MUST be registered   --------------------- */ ?>
	<?php if ($reg_proxy) : ?>
		<?php if (!$proxyCnt) : ?>
			<div class="center"><?php echo Text::_('COM_GAVOTING_NOPROXY_REGISTERED'); ?></div>
		<?php else : ?>
		    <?php if ($proxy_type == 1 || $proxy_type == 2 || ($proxy_type == 0 && !$dupl_vote)) : ?>
				<?php echo $nominations->form->renderField('proxy_vote'); ?>
				<?php echo $nominations->form->renderField('proxy_for'); ?>
		    <?php else : ?>
				<input type="hidden" name="jform[proxy_vote]" value="0" />
				<input type="hidden" name="jform[proxy_for]" value="0" />
			<?php endif; ?>
		    <?php if ($proxy_type == 2) : ?>
				<?php echo $nominations->form->renderField('comment'); ?>
		    <?php endif; ?>
		<?php endif; ?>
	<?php /* ------------  Registration of proxy delegates NOT necessary   -------------- */ ?>
	<?php else : ?>
	    <?php if ($proxy_type == 1 || $proxy_type == 2 || ($proxy_type == 0 && !$dupl_vote)) : ?>
			<?php echo $nominations->form->renderField('proxy_vote'); ?>
			<?php echo $nominations->form->renderField('proxy_for'); ?>
	    <?php else : ?>
			<input type="hidden" name="jform[proxy_vote]" value="0" />
			<input type="hidden" name="jform[proxy_for]" value="0" />
		<?php endif; ?>
	    <?php if ($proxy_type == 2) : ?>
			<?php echo $nominations->form->renderField('comment'); ?>
	    <?php endif; ?>
	<?php endif; ?>

	<?php /* ------------  Cycle through the nomination records for choosing   -------------- */ ?>
	<?php /* the nominations are in an array of position arrays and then each position array is an array of nominations */ ?>
	<?php foreach ($nominations->nominations AS $key => $position) : $NomCntr = 0; ?>

		<?php if (is_array($position) && !empty($position)) : ?>

			<div class="control-group">
				<div class="control-label">
					<label id="jform_nom_ids_lbl" for="jform_nom_ids_<?php echo $key; ?>">
						<?php echo $position[0]->position_id_name; ?>
					</label>
				</div>
				<div class="controls extrawide">

					<?php if ($position[0]->pos_qty == 1) : ?>
						<select id="jform_nom_ids_nom_id<?php echo $key; ?>"
								name="jform[nom_ids][nom_id<?php echo $key; ?>]">
							<option value="0"> - <?php echo Text::_('COM_GAVOTING_SELECT_NOMINATION'); ?> - </option>
							<?php foreach ($position AS $nom) : ?>
								<option value="<?php echo $nom->id; ?>"><?php echo $nom->nomination_name; ?></option>
							<?php endforeach; ?>
						</select>
                    <?php else : ?>
						<?php foreach ($position AS $nom) : $NomCntr++; ?>
							<?php if ($NomCntr == 1) : ?>
								<?php echo '<br />'.Text::sprintf('COM_GAVOTING_MULTIPLE_POSITIONS', $nom->pos_qty, $nom->pos_qty); ?>
							<?php endif; ?>
							<div class="checkbox">
								<label id="jform_nom_ids_lbl" for="jform_nom_ids_<?php echo $key; ?>" class="checkbox">
									<?php echo $nom->nomination_name; ?>
									<input type="checkbox" name="jform[nom_ids][nom_id<?php echo $key; ?>][nom_id<?php echo $nom->id; ?>]" value="<?php echo $nom->id; ?>" />
								</label>
							</div>
						<?php endforeach; ?>
					<?php endif; ?>

				</div>
			</div>
		<?php endif; ?>

	<?php endforeach; ?>

	<div class="control-group">
		<div class="controls">
			<?php if ($nominations->canSave): ?>
				<button type="submit" class="validate btn btn-primary">
					<?php echo Text::_('JSUBMIT'); ?>
				</button>
			<?php endif; ?>
			<a class="btn btn-secondary"
			   href="<?php echo Route::_('index.php?option=com_gavoting&task=voterform.cancel'); ?>"
			   title="<?php echo Text::_('JCANCEL'); ?>">
				<?php echo Text::_('JCANCEL'); ?>
			</a>
		</div>
	</div>

	<input type="hidden" name="option" value="com_gavoting"/>
	<input type="hidden" name="task" value="voterform.save"/>
	<?php echo HTMLHelper::_('form.token'); ?>
</form>
